@@ -40,14 +40,14 @@ plot(sim)
 
 
 ###################################################
-### code chunk number 5: article.Rnw:240-242 (eval = FALSE)
+### code chunk number 5: article.Rnw:239-241 (eval = FALSE)
 ###################################################
 ## res <- svsample(ret, priormu = c(-10, 1), priorphi = c(20, 1.1),
 ##   priorsigma = 0.1)
 
 
 ###################################################
-### code chunk number 6: article.Rnw:245-251
+### code chunk number 6: article.Rnw:244-250
 ###################################################
 if (usePreCalcResultsExtra) {
  load("vignette_sampling_draws1.RData")
@@ -58,7 +58,7 @@ if (usePreCalcResultsExtra) {
 
 
 ###################################################
-### code chunk number 7: article.Rnw:273-274
+### code chunk number 7: article.Rnw:272-273
 ###################################################
 summary(res, showlatent = FALSE)
 
@@ -87,7 +87,7 @@ paratraceplot(res)
 ### code chunk number 11: usd6
 ###################################################
 par(mfrow = c(1, 3))
-paradensplot(res)
+paradensplot(res, showobs = FALSE)
 
 
 ###################################################
@@ -104,7 +104,7 @@ plot(myresid, ret)
 
 
 ###################################################
-### code chunk number 14: article.Rnw:405-411
+### code chunk number 14: article.Rnw:404-410
 ###################################################
 set.seed(123456)
 n <- 1000
@@ -115,7 +115,7 @@ y <- rnorm(n, X %*% beta.true, sigma.true)
 
 
 ###################################################
-### code chunk number 15: article.Rnw:415-421
+### code chunk number 15: article.Rnw:414-420
 ###################################################
 burnin <- 100
 draws <- 5000
@@ -126,7 +126,7 @@ C0 <- 0.001
 
 
 ###################################################
-### code chunk number 16: article.Rnw:424-428
+### code chunk number 16: article.Rnw:423-427
 ###################################################
 p <- ncol(X)
 preCov <- solve(crossprod(X) + B0inv)
@@ -135,7 +135,7 @@ preDf <- c0 + n/2 + p/2
 
 
 ###################################################
-### code chunk number 17: article.Rnw:431-434
+### code chunk number 17: article.Rnw:430-433
 ###################################################
 draws1 <- matrix(NA_real_, nrow = draws, ncol = p + 1)
 colnames(draws1) <- c(paste("beta", 0:(p-1), sep = "_"), "sigma")
@@ -143,7 +143,7 @@ sigma2draw <- 1
 
 
 ###################################################
-### code chunk number 18: article.Rnw:437-445
+### code chunk number 18: article.Rnw:436-444
 ###################################################
 for (i in -(burnin-1):draws) {
   betadraw <- as.numeric(mvtnorm::rmvnorm(1, preMean,
@@ -156,7 +156,7 @@ for (i in -(burnin-1):draws) {
 
 
 ###################################################
-### code chunk number 19: article.Rnw:448-449
+### code chunk number 19: article.Rnw:447-448
 ###################################################
 colMeans(draws1)
 
@@ -169,13 +169,13 @@ plot(coda::mcmc(draws1), show.obs = FALSE)
 
 
 ###################################################
-### code chunk number 21: article.Rnw:459-460 (eval = FALSE)
+### code chunk number 21: article.Rnw:458-459 (eval = FALSE)
 ###################################################
 ## plot(coda::mcmc(draws1), show.obs = FALSE)
 
 
 ###################################################
-### code chunk number 22: article.Rnw:482-487
+### code chunk number 22: article.Rnw:481-486
 ###################################################
 mu.true <- log(sigma.true^2)
 phi.true <- 0.97
@@ -185,7 +185,7 @@ y <- X %*% beta.true + simresid$y
 
 
 ###################################################
-### code chunk number 23: article.Rnw:490-496
+### code chunk number 23: article.Rnw:489-495
 ###################################################
 draws <- 50000
 burnin <- 1000
@@ -196,7 +196,7 @@ priorsigma <- 1
 
 
 ###################################################
-### code chunk number 24: article.Rnw:499-506
+### code chunk number 24: article.Rnw:498-505
 ###################################################
 draws2 <- matrix(NA_real_, nrow = floor(draws / thinning),
   ncol = 3 + n + p)
@@ -208,7 +208,7 @@ svdraw <- list(para = c(mu = -10, phi = 0.9, sigma = 0.2),
 
 
 ###################################################
-### code chunk number 25: article.Rnw:513-530 (eval = FALSE)
+### code chunk number 25: article.Rnw:512-529 (eval = FALSE)
 ###################################################
 ## for (i in -(burnin-1):draws) {
 ##   ytilde <- y - X %*% betadraw
@@ -230,7 +230,7 @@ svdraw <- list(para = c(mu = -10, phi = 0.9, sigma = 0.2),
 
 
 ###################################################
-### code chunk number 26: article.Rnw:533-562
+### code chunk number 26: article.Rnw:532-561
 ###################################################
 if (usePreCalcResults) {
  load("vignette_sampling_draws2.RData")
@@ -264,7 +264,7 @@ for (i in -(burnin-1):draws) {
 
 
 ###################################################
-### code chunk number 27: article.Rnw:566-567 (eval = FALSE)
+### code chunk number 27: article.Rnw:565-566 (eval = FALSE)
 ###################################################
 ## plot(coda::mcmc(draws2[, 4:7]), show.obs = FALSE)
 
@@ -277,13 +277,13 @@ plot(coda::mcmc(draws2selection[, 1:4]), show.obs = FALSE)
 
 
 ###################################################
-### code chunk number 29: article.Rnw:585-586 (eval = FALSE)
+### code chunk number 29: article.Rnw:584-585 (eval = FALSE)
 ###################################################
 ## colMeans(draws2[, 4:8])
 
 
 ###################################################
-### code chunk number 30: article.Rnw:589-590
+### code chunk number 30: article.Rnw:588-589
 ###################################################
 colMeans(draws2selection)
 
@@ -302,7 +302,7 @@ abline(0,1)
 
 
 ###################################################
-### code chunk number 32: article.Rnw:655-876
+### code chunk number 32: article.Rnw:654-875
 ###################################################
 if (usePreCalcResults) {
  load("vignette_sampling_realworld.RData")
