@@ -45,7 +45,6 @@ void progressbar_finish(int N);
 // to store (some) values of h
 inline void store_h(double * h, double * hstore, int timethin,
                     int hstorelength,
-                    double * tau, double * taustore, 
 		    double h0, double * h0store,
 		    Rcpp::NumericVector curpara,
 		    bool centered_baseline) {
@@ -57,18 +56,25 @@ inline void store_h(double * h, double * hstore, int timethin,
   for (int j = 0; j < hstorelength; j++) hstore[j] = curpara[0] + curpara[2]*h[timethin*j];
   *h0store = curpara[0] + curpara[2]*h0;
  }
- //for (int j = 0; j < hstorelength; j++) taustore[j] = tau[timethin*j];
+}
+
+// to store (some) values of tau
+inline void store_tau(double * tau, double * taustore, int timethin, int hstorelength) {
+ for (int j = 0; j < hstorelength; j++) taustore[j] = tau[timethin*j];
 }
 
 // b)
 // Cholesky factor for a tridiagonal matrix with constant off-diagonal
-void cholTridiag(const Rcpp::NumericVector & omega_diag, double omega_offdiag, double * chol_diag, double * chol_offdiag);
+void cholTridiag(const Rcpp::NumericVector & omega_diag, double omega_offdiag,
+                 double * chol_diag, double * chol_offdiag);
 
 // Solves Chol*x = covector ("forward algorithm")
-void forwardAlg(const Rcpp::NumericVector & chol_diag, const Rcpp::NumericVector & chol_offdiag, const Rcpp::NumericVector & covector, double * htmp);
+void forwardAlg(const Rcpp::NumericVector & chol_diag, const Rcpp::NumericVector & chol_offdiag,
+                const Rcpp::NumericVector & covector, double * htmp);
 
 // Solves (Chol')*x = htmp ("backward algorithm")
-void backwardAlg(const Rcpp::NumericVector & chol_diag, const Rcpp::NumericVector & chol_offdiag, const Rcpp::NumericVector & htmp, double * h);
+void backwardAlg(const Rcpp::NumericVector & chol_diag, const Rcpp::NumericVector & chol_offdiag,
+                 const Rcpp::NumericVector & htmp, double * h);
 
 // c)
 // draws length(r) RVs, expects the non-normalized CDF mixprob
